@@ -1,13 +1,26 @@
 package Dist::Zilla::Plugin::MojibakeTests;
-# ABSTRACT: Release tests for source encoding
+# ABSTRACT: Author tests for source encoding
 
 use strict;
 use warnings qw(all);
 
-our $VERSION = '0.7'; # VERSION
+our $VERSION = '0.8'; # VERSION
 
 use Moose;
 extends q(Dist::Zilla::Plugin::InlineFiles);
+with 'Dist::Zilla::Role::PrereqSource';
+
+
+sub register_prereqs {
+    my $self = shift;
+    return $self->zilla->register_prereqs(
+        {
+            type  => 'requires',
+            phase => 'develop',
+        },
+        'Test::Mojibake' => 0,
+    );
+}
 
 __PACKAGE__->meta->make_immutable;
 no Moose;
@@ -20,11 +33,11 @@ no Moose;
 
 =head1 NAME
 
-Dist::Zilla::Plugin::MojibakeTests - Release tests for source encoding
+Dist::Zilla::Plugin::MojibakeTests - Author tests for source encoding
 
 =head1 VERSION
 
-version 0.7
+version 0.8
 
 =head1 SYNOPSIS
 
@@ -36,7 +49,9 @@ In F<dist.ini>:
 
 This is an extension of L<Dist::Zilla::Plugin::InlineFiles>, providing the following file:
 
-    xt/release/mojibake.t - a standard Test::Mojibake test
+    xt/author/mojibake.t - a standard Test::Mojibake test
+
+=for Pod::Coverage register_prereqs
 
 =for test_synopsis 1;
 __END__
@@ -55,16 +70,13 @@ the same terms as the Perl 5 programming language system itself.
 =cut
 
 __DATA__
-___[ xt/release/mojibake.t ]___
+___[ xt/author/mojibake.t ]___
 #!perl
 
 use strict;
 use warnings qw(all);
 
 use Test::More;
-
-## no critic (ProhibitStringyEval, RequireCheckingReturnValueOfEval)
-eval q(use Test::Mojibake);
-plan skip_all => q(Test::Mojibake required for source encoding testing) if $@;
+use Test::Mojibake;
 
 all_files_encoding_ok();
